@@ -1,4 +1,4 @@
-# Gufw 17.04.0 - http://gufw.org
+# Gufw 17.04.1 - http://gufw.org
 # Copyright (C) 2008-2016 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
@@ -270,7 +270,7 @@ class Update:
                 real_row = self.gufw.rules_model.get_value(iter_row, 14)
                 if cmd == rule_cmd:
                     rules_rows.append(real_row)
-            except:
+            except Exception:
                 rules_rows = sorted(rules_rows, key=int, reverse=True)
                 return rules_rows
             i += 1
